package org.jeecg.modules.common.controller;

import cn.hutool.core.util.StrUtil;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.jeecg.common.entity.BaseEntity;
import org.jeecg.common.system.base.controller.JeecgController;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.modules.common.entity.CsHttpLog;
import org.jeecg.modules.common.service.ICsHttpLogService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.Arrays;

 /**
 * @Description: 第三方接口日志表
 * @Author: jeecg-boot
 * @Date:   2023-12-05
 * @Version: V1.0
 */
@Api(tags="第三方接口日志表")
@RestController
@RequestMapping("/cshttplog/csHttpLog")
@Slf4j
public class CsHttpLogController extends JeecgController<CsHttpLog, ICsHttpLogService> {
	@Autowired
	private ICsHttpLogService csHttpLogService;

	/**
	 * 分页列表查询
	 *
	 * @param csHttpLog
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "第三方接口日志表-分页列表查询")
	@ApiOperation(value="第三方接口日志表-分页列表查询", notes="第三方接口日志表-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<CsHttpLog>> queryPageList(CsHttpLog csHttpLog,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		LambdaQueryWrapper<CsHttpLog> queryWrapper = new LambdaQueryWrapper<>();

		//是否查询详情 true是 查询返回查询 否查询列表
		if (!csHttpLog.isCxxq()){
			queryWrapper.select(CsHttpLog::getId,CsHttpLog::getCreateBy,CsHttpLog::getCreateTime,
					CsHttpLog::getUpdateTime,CsHttpLog::getUpdateBy,CsHttpLog::getSysOrgCode,
					CsHttpLog::getTenantId,CsHttpLog::getCompanyId,CsHttpLog::getNsrsbh,
					CsHttpLog::getQqsj,CsHttpLog::getFhsj,CsHttpLog::getJklx,CsHttpLog::getGnbh,
					CsHttpLog::getGuid,CsHttpLog::getQqdz,
					//CsHttpLog::getQqrz,CsHttpLog::getFhrz,
					CsHttpLog::getQqhs,CsHttpLog::getQqlx);
		}

		queryWrapper.ge(csHttpLog.getQqsj()!=null,CsHttpLog::getQqsj,csHttpLog.getQqsj())
				.le(csHttpLog.getFhsj()!=null,CsHttpLog::getFhsj,csHttpLog.getFhsj())
				.eq(StrUtil.isNotBlank(csHttpLog.getGuid()),CsHttpLog::getGuid,csHttpLog.getGuid())
				.eq(StrUtil.isNotBlank(csHttpLog.getJklx()),CsHttpLog::getJklx,csHttpLog.getJklx())
				.eq(StrUtil.isNotBlank(csHttpLog.getNsrsbh()),CsHttpLog::getNsrsbh,csHttpLog.getNsrsbh())
				.eq(StrUtil.isNotBlank(csHttpLog.getGnbh()),CsHttpLog::getGnbh,csHttpLog.getGnbh())
				.eq(StrUtil.isNotBlank(csHttpLog.getId()),CsHttpLog::getId,csHttpLog.getId())
				.orderByDesc(BaseEntity::getCreateTime);
		Page<CsHttpLog> page = new Page<CsHttpLog>(pageNo, pageSize);
		IPage<CsHttpLog> pageList = csHttpLogService.page(page, queryWrapper);
		return Result.OK(pageList);
	}

	/**
	 *   添加
	 *
	 * @param csHttpLog
	 * @return
	 */
	@AutoLog(value = "第三方接口日志表-添加")
	@ApiOperation(value="第三方接口日志表-添加", notes="第三方接口日志表-添加")
	//@RequiresPermissions("cshttplog:cs_http_log:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody CsHttpLog csHttpLog) {
		csHttpLogService.save(csHttpLog);
		return Result.OK("添加成功！");
	}

	/**
	 *  编辑
	 *
	 * @param csHttpLog
	 * @return
	 */
	@AutoLog(value = "第三方接口日志表-编辑")
	@ApiOperation(value="第三方接口日志表-编辑", notes="第三方接口日志表-编辑")
	//@RequiresPermissions("cshttplog:cs_http_log:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody CsHttpLog csHttpLog) {
		csHttpLogService.updateById(csHttpLog);
		return Result.OK("编辑成功!");
	}

	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "第三方接口日志表-通过id删除")
	@ApiOperation(value="第三方接口日志表-通过id删除", notes="第三方接口日志表-通过id删除")
	//@RequiresPermissions("cshttplog:cs_http_log:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		csHttpLogService.removeById(id);
		return Result.OK("删除成功!");
	}

	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "第三方接口日志表-批量删除")
	@ApiOperation(value="第三方接口日志表-批量删除", notes="第三方接口日志表-批量删除")
	//@RequiresPermissions("cshttplog:cs_http_log:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.csHttpLogService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}

	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "第三方接口日志表-通过id查询")
	@ApiOperation(value="第三方接口日志表-通过id查询", notes="第三方接口日志表-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<CsHttpLog> queryById(@RequestParam(name="id",required=true) String id) {
		CsHttpLog csHttpLog = csHttpLogService.getById(id);
		if(csHttpLog==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(csHttpLog);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param csHttpLog
    */
    //@RequiresPermissions("cshttplog:cs_http_log:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, CsHttpLog csHttpLog) {
        return super.exportXls(request, csHttpLog, CsHttpLog.class, "第三方接口日志表");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    //@RequiresPermissions("cshttplog:cs_http_log:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, CsHttpLog.class);
    }

}
