package org.jeecg.modules.jfptpz.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.jeecg.common.system.base.controller.JeecgController;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.modules.jfptpz.entity.CsPtJfptpz;
import org.jeecg.modules.jfptpz.service.ICsPtJfptpzService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.Arrays;

 /**
 * @Description: 交付平台配置
 * @Author: jeecg-boot
 * @Date:   2023-11-08
 * @Version: V1.0
 */
@Api(tags="交付平台配置")
@RestController
@RequestMapping("/jfptpz/csPtJfptpz")
@Slf4j
public class CsPtJfptpzController extends JeecgController<CsPtJfptpz, ICsPtJfptpzService> {
	@Autowired
	private ICsPtJfptpzService csPtJfptpzService;
	
	/**
	 * 分页列表查询
	 *
	 * @param csPtJfptpz
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "交付平台配置-分页列表查询")
	@ApiOperation(value="交付平台配置-分页列表查询", notes="交付平台配置-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<CsPtJfptpz>> queryPageList(CsPtJfptpz csPtJfptpz,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<CsPtJfptpz> queryWrapper = QueryGenerator.initQueryWrapper(csPtJfptpz, req.getParameterMap());
		Page<CsPtJfptpz> page = new Page<CsPtJfptpz>(pageNo, pageSize);
		IPage<CsPtJfptpz> pageList = csPtJfptpzService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param csPtJfptpz
	 * @return
	 */
	@AutoLog(value = "交付平台配置-添加")
	@ApiOperation(value="交付平台配置-添加", notes="交付平台配置-添加")
	@RequiresPermissions("jfptpz:cs_pt_jfptpz:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody CsPtJfptpz csPtJfptpz) {
		csPtJfptpzService.save(csPtJfptpz);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param csPtJfptpz
	 * @return
	 */
	@AutoLog(value = "交付平台配置-编辑")
	@ApiOperation(value="交付平台配置-编辑", notes="交付平台配置-编辑")
	@RequiresPermissions("jfptpz:cs_pt_jfptpz:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody CsPtJfptpz csPtJfptpz) {
		csPtJfptpzService.updateById(csPtJfptpz);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "交付平台配置-通过id删除")
	@ApiOperation(value="交付平台配置-通过id删除", notes="交付平台配置-通过id删除")
	@RequiresPermissions("jfptpz:cs_pt_jfptpz:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		csPtJfptpzService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "交付平台配置-批量删除")
	@ApiOperation(value="交付平台配置-批量删除", notes="交付平台配置-批量删除")
	@RequiresPermissions("jfptpz:cs_pt_jfptpz:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.csPtJfptpzService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "交付平台配置-通过id查询")
	@ApiOperation(value="交付平台配置-通过id查询", notes="交付平台配置-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<CsPtJfptpz> queryById(@RequestParam(name="id",required=true) String id) {
		CsPtJfptpz csPtJfptpz = csPtJfptpzService.getById(id);
		if(csPtJfptpz==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(csPtJfptpz);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param csPtJfptpz
    */
    @RequiresPermissions("jfptpz:cs_pt_jfptpz:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, CsPtJfptpz csPtJfptpz) {
        return super.exportXls(request, csPtJfptpz, CsPtJfptpz.class, "交付平台配置");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("jfptpz:cs_pt_jfptpz:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, CsPtJfptpz.class);
    }

}
