package org.jeecg.modules.kzzdys.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.shiro.SecurityUtils;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.system.vo.LoginUser;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.kzzdys.entity.CsPtKzzdys;
import org.jeecg.modules.kzzdys.entity.CsPtKzzdysmx;
import org.jeecg.modules.kzzdys.service.ICsPtKzzdysService;
import org.jeecg.modules.kzzdys.service.ICsPtKzzdysmxService;
import org.jeecg.modules.kzzdys.vo.CsPtKzzdysPage;
import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.io.IOException;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.Map;


 /**
 * @Description: 扩展字段映射设置
 * @Author: jeecg-boot
 * @Date:   2023-12-07
 * @Version: V1.0
 */
@Api(tags="扩展字段映射设置")
@RestController
@RequestMapping("/kzzdys/csPtKzzdys")
@Slf4j
public class CsPtKzzdysController {
	@Autowired
	private ICsPtKzzdysService csPtKzzdysService;
	@Autowired
	private ICsPtKzzdysmxService csPtKzzdysmxService;

	/**
	 * 分页列表查询
	 *
	 * @param csPtKzzdys
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "扩展字段映射设置-分页列表查询")
	@ApiOperation(value="扩展字段映射设置-分页列表查询", notes="扩展字段映射设置-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<CsPtKzzdys>> queryPageList(CsPtKzzdys csPtKzzdys,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<CsPtKzzdys> queryWrapper = QueryGenerator.initQueryWrapper(csPtKzzdys, req.getParameterMap());
		Page<CsPtKzzdys> page = new Page<CsPtKzzdys>(pageNo, pageSize);
		IPage<CsPtKzzdys> pageList = csPtKzzdysService.page(page, queryWrapper);
		return Result.OK(pageList);
	}

	/**
	 *   添加
	 *
	 * @param csPtKzzdysPage
	 * @return
	 */
	@AutoLog(value = "扩展字段映射设置-添加")
	@ApiOperation(value="扩展字段映射设置-添加", notes="扩展字段映射设置-添加")
    //@RequiresPermissions("kzzdys:cs_pt_kzzdys:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody CsPtKzzdysPage csPtKzzdysPage) {
		CsPtKzzdys csPtKzzdys = new CsPtKzzdys();
		BeanUtils.copyProperties(csPtKzzdysPage, csPtKzzdys);
		csPtKzzdysService.saveMain(csPtKzzdys, csPtKzzdysPage.getCsPtKzzdysmxList());
		return Result.OK("添加成功！");
	}

	/**
	 *  编辑
	 *
	 * @param csPtKzzdysPage
	 * @return
	 */
	@AutoLog(value = "扩展字段映射设置-编辑")
	@ApiOperation(value="扩展字段映射设置-编辑", notes="扩展字段映射设置-编辑")
    //@RequiresPermissions("kzzdys:cs_pt_kzzdys:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody CsPtKzzdysPage csPtKzzdysPage) {
		CsPtKzzdys csPtKzzdys = new CsPtKzzdys();
		BeanUtils.copyProperties(csPtKzzdysPage, csPtKzzdys);
		CsPtKzzdys csPtKzzdysEntity = csPtKzzdysService.getById(csPtKzzdys.getId());
		if(csPtKzzdysEntity==null) {
			return Result.error("未找到对应数据");
		}
		csPtKzzdysService.updateMain(csPtKzzdys, csPtKzzdysPage.getCsPtKzzdysmxList());
		return Result.OK("编辑成功!");
	}

	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "扩展字段映射设置-通过id删除")
	@ApiOperation(value="扩展字段映射设置-通过id删除", notes="扩展字段映射设置-通过id删除")
    //@RequiresPermissions("kzzdys:cs_pt_kzzdys:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		csPtKzzdysService.delMain(id);
		return Result.OK("删除成功!");
	}

	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "扩展字段映射设置-批量删除")
	@ApiOperation(value="扩展字段映射设置-批量删除", notes="扩展字段映射设置-批量删除")
    //@RequiresPermissions("kzzdys:cs_pt_kzzdys:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.csPtKzzdysService.delBatchMain(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功！");
	}

	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "扩展字段映射设置-通过id查询")
	@ApiOperation(value="扩展字段映射设置-通过id查询", notes="扩展字段映射设置-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<CsPtKzzdys> queryById(@RequestParam(name="id",required=true) String id) {
		CsPtKzzdys csPtKzzdys = csPtKzzdysService.getById(id);
		if(csPtKzzdys==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(csPtKzzdys);

	}
	 /**
	  * 通过id查询
	  *
	  * @param ysbm
	  * @return
	  */
	 //@AutoLog(value = "扩展字段映射设置-通过id查询")
	 @ApiOperation(value="扩展字段映射设置-通过ysbm查询", notes="扩展字段映射设置-通过ysbm查询")
	 @GetMapping(value = "/queryByYsbm")
	 public Result<CsPtKzzdys> queryByYsbm(@RequestParam(name="ysbm",required=true) String ysbm) {
		 CsPtKzzdys csPtKzzdys = csPtKzzdysService.lambdaQuery().eq(CsPtKzzdys::getYsbm, ysbm).one();
		 if(csPtKzzdys==null) {
			 return Result.OK(new CsPtKzzdys());
		 }else{
			 List<CsPtKzzdysmx> csPtKzzdysmxList = csPtKzzdysmxService.selectByMainId(csPtKzzdys.getId());
			 csPtKzzdys.setKzzdysmx(csPtKzzdysmxList);
		 }
		 return Result.OK(csPtKzzdys);
	 }
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "扩展字段映射明细通过主表ID查询")
	@ApiOperation(value="扩展字段映射明细主表ID查询", notes="扩展字段映射明细-通主表ID查询")
	@GetMapping(value = "/queryCsPtKzzdysmxByMainId")
	public Result<List<CsPtKzzdysmx>> queryCsPtKzzdysmxListByMainId(@RequestParam(name="id",required=true) String id) {
		List<CsPtKzzdysmx> csPtKzzdysmxList = csPtKzzdysmxService.selectByMainId(id);
		return Result.OK(csPtKzzdysmxList);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param csPtKzzdys
    */
    @RequiresPermissions("kzzdys:cs_pt_kzzdys:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, CsPtKzzdys csPtKzzdys) {
      // Step.1 组装查询条件查询数据
      QueryWrapper<CsPtKzzdys> queryWrapper = QueryGenerator.initQueryWrapper(csPtKzzdys, request.getParameterMap());
      LoginUser sysUser = (LoginUser) SecurityUtils.getSubject().getPrincipal();

      //配置选中数据查询条件
      String selections = request.getParameter("selections");
      if(oConvertUtils.isNotEmpty(selections)) {
         List<String> selectionList = Arrays.asList(selections.split(","));
         queryWrapper.in("id",selectionList);
      }
      //Step.2 获取导出数据
      List<CsPtKzzdys> csPtKzzdysList = csPtKzzdysService.list(queryWrapper);

      // Step.3 组装pageList
      List<CsPtKzzdysPage> pageList = new ArrayList<CsPtKzzdysPage>();
      for (CsPtKzzdys main : csPtKzzdysList) {
          CsPtKzzdysPage vo = new CsPtKzzdysPage();
          BeanUtils.copyProperties(main, vo);
          List<CsPtKzzdysmx> csPtKzzdysmxList = csPtKzzdysmxService.selectByMainId(main.getId());
          vo.setCsPtKzzdysmxList(csPtKzzdysmxList);
          pageList.add(vo);
      }

      // Step.4 AutoPoi 导出Excel
      ModelAndView mv = new ModelAndView(new JeecgEntityExcelView());
      mv.addObject(NormalExcelConstants.FILE_NAME, "扩展字段映射设置列表");
      mv.addObject(NormalExcelConstants.CLASS, CsPtKzzdysPage.class);
      mv.addObject(NormalExcelConstants.PARAMS, new ExportParams("扩展字段映射设置数据", "导出人:"+sysUser.getRealname(), "扩展字段映射设置"));
      mv.addObject(NormalExcelConstants.DATA_LIST, pageList);
      return mv;
    }

    /**
    * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    //@RequiresPermissions("kzzdys:cs_pt_kzzdys:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
      MultipartHttpServletRequest multipartRequest = (MultipartHttpServletRequest) request;
      Map<String, MultipartFile> fileMap = multipartRequest.getFileMap();
      for (Map.Entry<String, MultipartFile> entity : fileMap.entrySet()) {
          // 获取上传文件对象
          MultipartFile file = entity.getValue();
          ImportParams params = new ImportParams();
          params.setTitleRows(2);
          params.setHeadRows(1);
          params.setNeedSave(true);
          try {
              List<CsPtKzzdysPage> list = ExcelImportUtil.importExcel(file.getInputStream(), CsPtKzzdysPage.class, params);
              for (CsPtKzzdysPage page : list) {
                  CsPtKzzdys po = new CsPtKzzdys();
                  BeanUtils.copyProperties(page, po);
                  csPtKzzdysService.saveMain(po, page.getCsPtKzzdysmxList());
              }
              return Result.OK("文件导入成功！数据行数:" + list.size());
          } catch (Exception e) {
              log.error(e.getMessage(),e);
              return Result.error("文件导入失败:"+e.getMessage());
          } finally {
              try {
                  file.getInputStream().close();
              } catch (IOException e) {
//                  e.printStackTrace();
				  log.error(e.getMessage(), e);
              }
          }
      }
      return Result.OK("文件导入失败！");
    }

}
