package org.jeecg.modules.shorturl.controller;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import lombok.extern.slf4j.Slf4j;
import org.apache.shiro.authz.annotation.RequiresPermissions;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.jeecg.common.system.base.controller.JeecgController;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.modules.shorturl.entity.CsPtShorturl;
import org.jeecg.modules.shorturl.service.ICsPtShorturlService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.servlet.ModelAndView;

import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import java.util.Arrays;

 /**
 * @Description: 短链接
 * @Author: jeecg-boot
 * @Date:   2023-11-05
 * @Version: V1.0
 */
@Api(tags="短链接")
@RestController
@RequestMapping("/shorturl/csPtShorturl")
@Slf4j
public class CsPtShorturlController extends JeecgController<CsPtShorturl, ICsPtShorturlService> {
	@Autowired
	private ICsPtShorturlService csPtShorturlService;
	
	/**
	 * 分页列表查询
	 *
	 * @param csPtShorturl
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "短链接-分页列表查询")
	@ApiOperation(value="短链接-分页列表查询", notes="短链接-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<CsPtShorturl>> queryPageList(CsPtShorturl csPtShorturl,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<CsPtShorturl> queryWrapper = QueryGenerator.initQueryWrapper(csPtShorturl, req.getParameterMap());
		Page<CsPtShorturl> page = new Page<CsPtShorturl>(pageNo, pageSize);
		IPage<CsPtShorturl> pageList = csPtShorturlService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param csPtShorturl
	 * @return
	 */
	@AutoLog(value = "短链接-添加")
	@ApiOperation(value="短链接-添加", notes="短链接-添加")
	@RequiresPermissions("shorturl:cs_pt_shorturl:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody CsPtShorturl csPtShorturl) {
		csPtShorturlService.save(csPtShorturl);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param csPtShorturl
	 * @return
	 */
	@AutoLog(value = "短链接-编辑")
	@ApiOperation(value="短链接-编辑", notes="短链接-编辑")
	@RequiresPermissions("shorturl:cs_pt_shorturl:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody CsPtShorturl csPtShorturl) {
		csPtShorturlService.updateById(csPtShorturl);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "短链接-通过id删除")
	@ApiOperation(value="短链接-通过id删除", notes="短链接-通过id删除")
	@RequiresPermissions("shorturl:cs_pt_shorturl:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		csPtShorturlService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "短链接-批量删除")
	@ApiOperation(value="短链接-批量删除", notes="短链接-批量删除")
	@RequiresPermissions("shorturl:cs_pt_shorturl:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.csPtShorturlService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "短链接-通过id查询")
	@ApiOperation(value="短链接-通过id查询", notes="短链接-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<CsPtShorturl> queryById(@RequestParam(name="id",required=true) String id) {
		CsPtShorturl csPtShorturl = csPtShorturlService.getById(id);
		if(csPtShorturl==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(csPtShorturl);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param csPtShorturl
    */
    @RequiresPermissions("shorturl:cs_pt_shorturl:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, CsPtShorturl csPtShorturl) {
        return super.exportXls(request, csPtShorturl, CsPtShorturl.class, "短链接");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("shorturl:cs_pt_shorturl:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, CsPtShorturl.class);
    }

}
