package org.jeecg.modules.sjly.controller;

import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;
import java.io.IOException;
import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import org.jeecg.common.api.vo.Result;
import org.jeecg.common.system.query.QueryGenerator;
import org.jeecg.common.util.oConvertUtils;
import org.jeecg.modules.sjly.entity.CsXxSjly;
import org.jeecg.modules.sjly.service.ICsXxSjlyService;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import lombok.extern.slf4j.Slf4j;

import org.jeecgframework.poi.excel.ExcelImportUtil;
import org.jeecgframework.poi.excel.def.NormalExcelConstants;
import org.jeecgframework.poi.excel.entity.ExportParams;
import org.jeecgframework.poi.excel.entity.ImportParams;
import org.jeecgframework.poi.excel.view.JeecgEntityExcelView;
import org.jeecg.common.system.base.controller.JeecgController;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;
import org.springframework.web.multipart.MultipartFile;
import org.springframework.web.multipart.MultipartHttpServletRequest;
import org.springframework.web.servlet.ModelAndView;
import com.alibaba.fastjson.JSON;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.jeecg.common.aspect.annotation.AutoLog;
import org.apache.shiro.authz.annotation.RequiresPermissions;

 /**
 * @Description: 数据来源
 * @Author: jeecg-boot
 * @Date:   2023-12-13
 * @Version: V1.0
 */
@Api(tags="数据来源")
@RestController
@RequestMapping("/sjly/csXxSjly")
@Slf4j
public class CsXxSjlyController extends JeecgController<CsXxSjly, ICsXxSjlyService> {
	@Autowired
	private ICsXxSjlyService csXxSjlyService;
	
	/**
	 * 分页列表查询
	 *
	 * @param csXxSjly
	 * @param pageNo
	 * @param pageSize
	 * @param req
	 * @return
	 */
	//@AutoLog(value = "数据来源-分页列表查询")
	@ApiOperation(value="数据来源-分页列表查询", notes="数据来源-分页列表查询")
	@GetMapping(value = "/list")
	public Result<IPage<CsXxSjly>> queryPageList(CsXxSjly csXxSjly,
								   @RequestParam(name="pageNo", defaultValue="1") Integer pageNo,
								   @RequestParam(name="pageSize", defaultValue="10") Integer pageSize,
								   HttpServletRequest req) {
		QueryWrapper<CsXxSjly> queryWrapper = QueryGenerator.initQueryWrapper(csXxSjly, req.getParameterMap());
		Page<CsXxSjly> page = new Page<CsXxSjly>(pageNo, pageSize);
		IPage<CsXxSjly> pageList = csXxSjlyService.page(page, queryWrapper);
		return Result.OK(pageList);
	}
	
	/**
	 *   添加
	 *
	 * @param csXxSjly
	 * @return
	 */
	@AutoLog(value = "数据来源-添加")
	@ApiOperation(value="数据来源-添加", notes="数据来源-添加")
	@RequiresPermissions("sjly:cs_xx_sjly:add")
	@PostMapping(value = "/add")
	public Result<String> add(@RequestBody CsXxSjly csXxSjly) {
		csXxSjlyService.save(csXxSjly);
		return Result.OK("添加成功！");
	}
	
	/**
	 *  编辑
	 *
	 * @param csXxSjly
	 * @return
	 */
	@AutoLog(value = "数据来源-编辑")
	@ApiOperation(value="数据来源-编辑", notes="数据来源-编辑")
	@RequiresPermissions("sjly:cs_xx_sjly:edit")
	@RequestMapping(value = "/edit", method = {RequestMethod.PUT,RequestMethod.POST})
	public Result<String> edit(@RequestBody CsXxSjly csXxSjly) {
		csXxSjlyService.updateById(csXxSjly);
		return Result.OK("编辑成功!");
	}
	
	/**
	 *   通过id删除
	 *
	 * @param id
	 * @return
	 */
	@AutoLog(value = "数据来源-通过id删除")
	@ApiOperation(value="数据来源-通过id删除", notes="数据来源-通过id删除")
	@RequiresPermissions("sjly:cs_xx_sjly:delete")
	@DeleteMapping(value = "/delete")
	public Result<String> delete(@RequestParam(name="id",required=true) String id) {
		csXxSjlyService.removeById(id);
		return Result.OK("删除成功!");
	}
	
	/**
	 *  批量删除
	 *
	 * @param ids
	 * @return
	 */
	@AutoLog(value = "数据来源-批量删除")
	@ApiOperation(value="数据来源-批量删除", notes="数据来源-批量删除")
	@RequiresPermissions("sjly:cs_xx_sjly:deleteBatch")
	@DeleteMapping(value = "/deleteBatch")
	public Result<String> deleteBatch(@RequestParam(name="ids",required=true) String ids) {
		this.csXxSjlyService.removeByIds(Arrays.asList(ids.split(",")));
		return Result.OK("批量删除成功!");
	}
	
	/**
	 * 通过id查询
	 *
	 * @param id
	 * @return
	 */
	//@AutoLog(value = "数据来源-通过id查询")
	@ApiOperation(value="数据来源-通过id查询", notes="数据来源-通过id查询")
	@GetMapping(value = "/queryById")
	public Result<CsXxSjly> queryById(@RequestParam(name="id",required=true) String id) {
		CsXxSjly csXxSjly = csXxSjlyService.getById(id);
		if(csXxSjly==null) {
			return Result.error("未找到对应数据");
		}
		return Result.OK(csXxSjly);
	}

    /**
    * 导出excel
    *
    * @param request
    * @param csXxSjly
    */
    @RequiresPermissions("sjly:cs_xx_sjly:exportXls")
    @RequestMapping(value = "/exportXls")
    public ModelAndView exportXls(HttpServletRequest request, CsXxSjly csXxSjly) {
        return super.exportXls(request, csXxSjly, CsXxSjly.class, "数据来源");
    }

    /**
      * 通过excel导入数据
    *
    * @param request
    * @param response
    * @return
    */
    @RequiresPermissions("sjly:cs_xx_sjly:importExcel")
    @RequestMapping(value = "/importExcel", method = RequestMethod.POST)
    public Result<?> importExcel(HttpServletRequest request, HttpServletResponse response) {
        return super.importExcel(request, response, CsXxSjly.class);
    }

}
